/******************************************************************
*	Use Sean Cokus's implementation of Matsumoto and Nishimura's 
* Mersenne Twister algorithm as a uniform random number generator.
*
* mrm, UMIST 12 August, 1998
*/
# include <time.h>	/* for clock() */

# include <math.h>

# define DEBUG_LEVEL 2
# include "tune_debug.h"

# include "mersenne.h"
# include "random.h"

/**************************************************************
*	The constant two_pi is required by std_normal() and
* table_o_std_normal(), but it gets its value here, in 
* init_random().
*/
double	two_pi ;	/* shared via random.h */


# ifndef NDEBUG	/* if debugging, check initialization */
/**********************************
*	Private variables
*/
	static int		init_done = 0 ;
	
# endif	/* ifndef NDEBUG */
/* ___________________________________________________________________ */

void init_random( unsigned long seed )
{
	seedMT( seed ) ;
	two_pi = 4.0 * acos( 0.0 ) ;

# ifndef NDEBUG	
	init_done = 1 ;	/* if debugging, note initialization	*/
# endif
}
/* __________________________________________________________________ */

Rand_type std_uniform()
/************************************************
*	Return a number in [0, 1).
*/
{
	uint32	rand_val ;
	
	assert( init_done ) ;	/* debugging stuff	*/
	
	rand_val = randomMT() ;
	return( rand_val/ (((double) MT_MAX) + 1.0) ) ;
}
/* __________________________________________________________________ */

void table_o_std_uniform( Rand_type *table, size_t n_vals )
/***************************************************************
*	Return a table full of numbers uniform in [0, 1).
*/
{
	size_t		j ;

	assert( init_done ) ;		/* debugging stuff	*/	
	assert( table != NULL ) ;	/* more of the same */
	
	for( j=0 ; j < n_vals ; j++ )
		table[j] = randomMT() / (((double) MT_MAX) + 1.0) ;
}
