/*********************************************************
*	These switches control the behaviour of a modified
* version of Jeff Thorne's program, divtime. The switches
* fall into three broad classes: those that have to do 
* with running the code on different platforms (Macs and
* unix boxen), those used during debugging and those 
* that permit one to control the ages of the leaf nodes.
*
* The distribution version of this file uses the settings
* described inLorber et al.
*/

# ifndef _switches_set_	/* Set these switches just once */
# define _switches_set_
/**************************************************************
* This first group of switches apply to both platforms
*
*	FREEZE_LEAF_AGES	Allow the user to fix the ages of 
*						leaf nodes to some nonzero value.
*						Not used in Korber et al.
*
*	TETHER_LEAF_AGES	Allow the user to impose priors on
*						the ages of the leaf nodes.
*						This is the choice Korber et al.
*
*	READ_COMMAND_LINE	Read the names of various input
*						and output files from the 
*						command line. The alternative
*						is to use the hard-coded names
*						described below. Used in Korber et al.,
*
*	IGNORE_PROP_TIME	Do not include the prior on the
*						proportional age of child nodes
*						as a function of depth in the 
*						tree.  This switch was on (that is,
*						# defined by Korber et al.)
*
*	SLICE_VOL_PRIOR		Apply a prior on the ages of the
*						non-root internal nodes that gives
*						equal likelihood to all configurations
*						for which the ages of the root remains 
*						unchanged. This is the choice of Korber
*						et al.
*
*	USE_LOGLIKE_ALWAYS	Include those terms arising 
*						from the log-likelihood whenever
*						making an acceptance/rejection
*						decision. The alternative,
*						implemented in Jeff Thorne's 
*						original code, is to have a
*						subclass of moves that preserve
*						the branch lengths. This is switch
*						was on (that is, # defined) for the 
*						work in Korber et al.													
*/
				
/* # define FREEZE_LEAF_AGES */
# define TETHER_LEAF_AGES
# define READ_COMMAND_LINE
# define IGNORE_PROP_TIME
# define SLICE_VOL_PRIOR
# define USE_LOGLIKE_ALWAYS

/*********************************************************
*	Define the names of some default input and output
* files. 
*/
# ifdef __MWERKS__
	# define PROGRAM_NAME	"MacDivT"	/* on the Mac */
# else
	# define PROGRAM_NAME	"divt"
# endif

# ifdef TETHER_LEAF_AGES
	# define INPUT_FILE		"dt_tether.in"
# else
	# define INPUT_FILE		"dt_freeze.in"
# endif

# ifdef NDEBUG
	# define PARAM_FILE		"dt.params"
# else
	# define PARAM_FILE		"dt_debug.params"
# endif

# define TREE_FILE		"dt.tree"
# define NODE_FILE		"dt.node"

# define SAMP_FILE		"dt.samples"
# define RATIO_FILE		"dt.ratios"
# define SEED_FILE		"dt.ranseed"	/* preserved random-number seed */

/*********************************************************
*	The next block of switches are platform specific.
**********************************************************/

# ifdef __MWERKS__	/* On the Mac	*/
/**********************************************************
* Here are two Mac-only switches:
*
*	If GOOD_MACOS_CITIZEN is defined the Mac version
* 	of the code does a rudimentary version of cooperative
* 	multi-tasking, calling SIOUXHandleOneEvent() once per
* 	cycle of the Markov-Chain Monte-Carlo in order to let 
* 	the OS and other apps have a few clock cycles.
*
*	If PROFILE is defined we use the Metrowerks profiler.
*/

# define GOOD_MACOS_CITIZEN
/* # define PROFILE */

# endif

/**********************************************************
*	One should not need to change anything below here.
***********************************************************/

# if (defined(__MWERKS__) && defined(GOOD_MACOS_CITIZEN))
/*************************************************************
*	If we're on the Mac, include some stuff to enable 
* cooperative multitasking.
*/
# include <SIOUX.h>		/* These first two permit a minimal		*/
# include <Events.h>	/* level of cooperative multi-tasking 	*/

# endif /* Cooperating on the Mac? */

# if (defined(__MWERKS__) && defined(PROFILE))
/**********************************************************
*	Profiling stuff on the Mac.
*/
	# define START_PROFILE	\
		if( ProfilerInit( collectSummary, bestTimeBase, 100, 40 ) ) { \
			fprintf( stderr, "Profiler sickness.\n" ) ; \
			return( 2 )  ; \
		}	

	# define FINISH_PROFILE		\
		ProfilerDump("\p::MacDivT.prof");
		
# else
/**********************************************************
*	If profiling is off or if we are on a unix box, the
* macros START_PROFILE and FINISH_PROFILE should do nothing.
*/
	# define START_PROFILE
	# define FINISH_PROFILE
	
# endif /* Profiling on the Mac */
# endif /* _switches_set_ yet? */
