/****************************************************
*	The functions whose prototypes are below
* help one choose an initial condition for the
* Markov Chain Monre Carlo calculation.
*
*
* mrm, UMIST, 3 December 1999
*/

# ifndef _divtime_init_hdr_	/* There can be only one . . . */
# define _divtime_init_hdr_
/***************************************************
*	This macro defines a limit used in test
* of smallness, for branch lengths and for temporal
* lengths of branches, in both dt_startup.c
* and tether_divtime.c
*/
# include <float.h>	/* DBL_EPSILON */

# define TINY_FRAC		(100.0 * DBL_EPSILON)

/********************************************
* More parameters used in the generation
* of the initial condition.
*/
# define SHORT_BRANCH	0.0001	/* These two minimum sizes should	*/
# define SLOW_RATE		0.00001	/* really be based on a survey of 	*/
								/* constraints and branch lengths	*/

/* used in initialize() */							
# define EXPAND_TIME	1.1		/* N.B. this must be > 1.0 */

/***************************************************
*	Prototypes from dt_startup.c
*/
	/* generate initial conditions */
void random_start(double *time, double *rate);
void mol_clock_start(double *time, double *rate);
void least_sq_start(double *time, double *rate);

	/* smooth away abrupt rate variations */
void smooth_rates(double *time, double *rate);

	/* survey tips and estimate rates from data there */
void tip_rate_heterogeneity(double *rate);
void rates_from_tips(double *mean_rate, double *rate_sd, 
					double time[], double branch_lengths[]);
					
	/* needed by random_start() */
double exptial(double explambda);

# endif /* _divtime_init_hdr_ */
