/*********************************************************
*	The macros and prototypes below control the 
* represenation and i/o of trees in a modified version
* of Jeff Thorne's divtime program
*
* mrm: Whalley Range, 22 August, 1999
*/

# ifndef _Tether_Tree_	/* There can be only one . . . */
# define _Tether_Tree_
/**********************************************************
*	These sizes are required in several places.
*/
# define MAX_TIPS	((size_t) 200)
# define MAX_NODES 	((size_t) (2*MAX_TIPS + 2))
# define NAME_LEN 	((size_t) 20)

/**************************************************************
*	The following macros help one access details of the tree's
* topology, which is recorded in the integer array tonode[][]. 
* A node can have MAX_KIDS child nodes and one parent 
* node. To get at these data, use
*
* 	n_children = tonode[nodenum][N_KIDS] = tonode[nodenum][0]
*
* The indices of the kids are
*
* 	{ tonode[nodenum][1], tonode[nodenum][2], ....
*									tonode[nodenum][n_children]  }.
*
* while the parent node's index is tonode[nodenum][PARENT].
*/
# define MAX_KIDS		2	/* we want only binary trees */	

# define N_KIDS			0	/* first element in tonode[j][]	*/
# define PARENT			(MAX_KIDS + 1)	/* last element in tonode[j][]	*/

/***************************************************
*	These macros are for check_tree()
*/
# define VERBOSE	1 
# define QUIET		0

/************************************************************
*	Define a structure to hold the tethering priors on
* the leaves.
*/
typedef struct {

	double	date, tau, lambda, max_val ;
	double	win_width, win_min, win_max ;
	
}	Tether_Prior_Data ;

/****************************************************************
*	Variables shared with tether_divtime.c. The most important
* is tonode[][], which is described above.
*/
extern int		nnodes, ntips, nbranches ;
extern int		**tonode ;	/* Holds tree topology, see above.	*/	
extern char		**name ;	/* Holds names of leaf nodes.		*/
extern double	*mean, *constraint ;
extern double	tip_date[], max_tip_date ;

extern Tether_Prior_Data	tethers[] ;

/****************************************************************
*	Prototypes from tether_tree.c
*/
int read_tree(FILE *infile);
void fprint_tree(FILE *outfile, double *lengths);
char *sprint_name(int whichnode);
int check_tree(int **tree_matrix, int N_nodes, int printQ);

# endif /* _Tether_Tree_ */
